"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.18
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from ory_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from ory_client.exceptions import ApiAttributeError



class ProjectBrandingTheme(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'created_at': (datetime,),  # noqa: E501
            'id': (str,),  # noqa: E501
            'name': (str,),  # noqa: E501
            'project_branding_id': (str,),  # noqa: E501
            'updated_at': (datetime,),  # noqa: E501
            'accent_default_color': (str,),  # noqa: E501
            'accent_disabled_color': (str,),  # noqa: E501
            'accent_emphasis_color': (str,),  # noqa: E501
            'accent_muted_color': (str,),  # noqa: E501
            'accent_subtle_color': (str,),  # noqa: E501
            'background_canvas_color': (str,),  # noqa: E501
            'background_subtle_color': (str,),  # noqa: E501
            'background_surface_color': (str,),  # noqa: E501
            'border_default_color': (str,),  # noqa: E501
            'error_default_color': (str,),  # noqa: E501
            'error_emphasis_color': (str,),  # noqa: E501
            'error_muted_color': (str,),  # noqa: E501
            'error_subtle_color': (str,),  # noqa: E501
            'foreground_default_color': (str,),  # noqa: E501
            'foreground_disabled_color': (str,),  # noqa: E501
            'foreground_muted_color': (str,),  # noqa: E501
            'foreground_on_accent_color': (str,),  # noqa: E501
            'foreground_on_dark_color': (str,),  # noqa: E501
            'foreground_on_disabled_color': (str,),  # noqa: E501
            'foreground_subtle_color': (str,),  # noqa: E501
            'input_background_color': (str,),  # noqa: E501
            'input_disabled_color': (str,),  # noqa: E501
            'input_placeholder_color': (str,),  # noqa: E501
            'input_text_color': (str,),  # noqa: E501
            'logo_type': (str,),  # noqa: E501
            'logo_url': (str,),  # noqa: E501
            'primary_color': (str,),  # noqa: E501
            'secondary_color': (str,),  # noqa: E501
            'success_emphasis_color': (str,),  # noqa: E501
            'text_default_color': (str,),  # noqa: E501
            'text_disabled_color': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'created_at': 'created_at',  # noqa: E501
        'id': 'id',  # noqa: E501
        'name': 'name',  # noqa: E501
        'project_branding_id': 'project_branding_id',  # noqa: E501
        'updated_at': 'updated_at',  # noqa: E501
        'accent_default_color': 'accent_default_color',  # noqa: E501
        'accent_disabled_color': 'accent_disabled_color',  # noqa: E501
        'accent_emphasis_color': 'accent_emphasis_color',  # noqa: E501
        'accent_muted_color': 'accent_muted_color',  # noqa: E501
        'accent_subtle_color': 'accent_subtle_color',  # noqa: E501
        'background_canvas_color': 'background_canvas_color',  # noqa: E501
        'background_subtle_color': 'background_subtle_color',  # noqa: E501
        'background_surface_color': 'background_surface_color',  # noqa: E501
        'border_default_color': 'border_default_color',  # noqa: E501
        'error_default_color': 'error_default_color',  # noqa: E501
        'error_emphasis_color': 'error_emphasis_color',  # noqa: E501
        'error_muted_color': 'error_muted_color',  # noqa: E501
        'error_subtle_color': 'error_subtle_color',  # noqa: E501
        'foreground_default_color': 'foreground_default_color',  # noqa: E501
        'foreground_disabled_color': 'foreground_disabled_color',  # noqa: E501
        'foreground_muted_color': 'foreground_muted_color',  # noqa: E501
        'foreground_on_accent_color': 'foreground_on_accent_color',  # noqa: E501
        'foreground_on_dark_color': 'foreground_on_dark_color',  # noqa: E501
        'foreground_on_disabled_color': 'foreground_on_disabled_color',  # noqa: E501
        'foreground_subtle_color': 'foreground_subtle_color',  # noqa: E501
        'input_background_color': 'input_background_color',  # noqa: E501
        'input_disabled_color': 'input_disabled_color',  # noqa: E501
        'input_placeholder_color': 'input_placeholder_color',  # noqa: E501
        'input_text_color': 'input_text_color',  # noqa: E501
        'logo_type': 'logo_type',  # noqa: E501
        'logo_url': 'logo_url',  # noqa: E501
        'primary_color': 'primary_color',  # noqa: E501
        'secondary_color': 'secondary_color',  # noqa: E501
        'success_emphasis_color': 'success_emphasis_color',  # noqa: E501
        'text_default_color': 'text_default_color',  # noqa: E501
        'text_disabled_color': 'text_disabled_color',  # noqa: E501
    }

    read_only_vars = {
        'created_at',  # noqa: E501
        'id',  # noqa: E501
        'updated_at',  # noqa: E501
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, created_at, id, name, project_branding_id, updated_at, *args, **kwargs):  # noqa: E501
        """ProjectBrandingTheme - a model defined in OpenAPI

        Args:
            created_at (datetime): The Customiation Creation Date
            id (str): The customization theme ID.
            name (str): The customization theme name.
            project_branding_id (str): The ProjectBranding ID this customization is associated with
            updated_at (datetime): Last Time Branding was Updated

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            accent_default_color (str): AccentDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_disabled_color (str): AccentDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_emphasis_color (str): AccentEmphasisColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_muted_color (str): AccentMutedColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_subtle_color (str): AccentSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            background_canvas_color (str): BackgroundCanvasColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            background_subtle_color (str): BackgroundSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            background_surface_color (str): BackgroundSurfaceColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            border_default_color (str): BorderDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_default_color (str): ErrorDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_emphasis_color (str): ErrorEmphasisColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_muted_color (str): ErrorMutedColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_subtle_color (str): ErrorSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_default_color (str): ForegroundDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_disabled_color (str): ForegroundDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_muted_color (str): ForegroundMutedColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_on_accent_color (str): ForegroundOnAccentColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_on_dark_color (str): ForegroundOnDarkColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_on_disabled_color (str): ForegroundOnDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_subtle_color (str): ForegroundSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_background_color (str): InputBackgroundColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_disabled_color (str): InputDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_placeholder_color (str): InputPlaceholderColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_text_color (str): InputTextColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            logo_type (str): Logo Type The Logo mime type.. [optional]  # noqa: E501
            logo_url (str): Logo URL Logo can be an https:// or base64:// URL. If the URL is not allowed, the logo will be stored inside the Ory Network storage bucket.. [optional]  # noqa: E501
            primary_color (str): Primary color is an hsla color value used to derive the other colors from for the Ory Account Experience theme.. [optional]  # noqa: E501
            secondary_color (str): Secondary color is a hsla color code used to derive the other colors from for the Ory Account Experience theme.. [optional]  # noqa: E501
            success_emphasis_color (str): SuccessEmphasisColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            text_default_color (str): TextDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            text_disabled_color (str): TextDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.created_at = created_at
        self.id = id
        self.name = name
        self.project_branding_id = project_branding_id
        self.updated_at = updated_at
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, name, project_branding_id, *args, **kwargs):  # noqa: E501
        """ProjectBrandingTheme - a model defined in OpenAPI

            name (str): The customization theme name.
            project_branding_id (str): The ProjectBranding ID this customization is associated with
        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            accent_default_color (str): AccentDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_disabled_color (str): AccentDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_emphasis_color (str): AccentEmphasisColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_muted_color (str): AccentMutedColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            accent_subtle_color (str): AccentSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            background_canvas_color (str): BackgroundCanvasColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            background_subtle_color (str): BackgroundSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            background_surface_color (str): BackgroundSurfaceColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            border_default_color (str): BorderDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_default_color (str): ErrorDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_emphasis_color (str): ErrorEmphasisColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_muted_color (str): ErrorMutedColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            error_subtle_color (str): ErrorSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_default_color (str): ForegroundDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_disabled_color (str): ForegroundDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_muted_color (str): ForegroundMutedColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_on_accent_color (str): ForegroundOnAccentColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_on_dark_color (str): ForegroundOnDarkColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_on_disabled_color (str): ForegroundOnDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            foreground_subtle_color (str): ForegroundSubtleColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_background_color (str): InputBackgroundColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_disabled_color (str): InputDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_placeholder_color (str): InputPlaceholderColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            input_text_color (str): InputTextColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            logo_type (str): Logo Type The Logo mime type.. [optional]  # noqa: E501
            logo_url (str): Logo URL Logo can be an https:// or base64:// URL. If the URL is not allowed, the logo will be stored inside the Ory Network storage bucket.. [optional]  # noqa: E501
            primary_color (str): Primary color is an hsla color value used to derive the other colors from for the Ory Account Experience theme.. [optional]  # noqa: E501
            secondary_color (str): Secondary color is a hsla color code used to derive the other colors from for the Ory Account Experience theme.. [optional]  # noqa: E501
            success_emphasis_color (str): SuccessEmphasisColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            text_default_color (str): TextDefaultColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
            text_disabled_color (str): TextDisabledColor is a hex color code used by the Ory Account Experience theme.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.name = name
        self.project_branding_id = project_branding_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v1.1.18
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.update_settings_flow_with_lookup_method import UpdateSettingsFlowWithLookupMethod
from ory_client.model.update_settings_flow_with_oidc_method import UpdateSettingsFlowWithOidcMethod
from ory_client.model.update_settings_flow_with_password_method import UpdateSettingsFlowWithPasswordMethod
from ory_client.model.update_settings_flow_with_profile_method import UpdateSettingsFlowWithProfileMethod
from ory_client.model.update_settings_flow_with_totp_method import UpdateSettingsFlowWithTotpMethod
from ory_client.model.update_settings_flow_with_web_authn_method import UpdateSettingsFlowWithWebAuthnMethod
globals()['UpdateSettingsFlowWithLookupMethod'] = UpdateSettingsFlowWithLookupMethod
globals()['UpdateSettingsFlowWithOidcMethod'] = UpdateSettingsFlowWithOidcMethod
globals()['UpdateSettingsFlowWithPasswordMethod'] = UpdateSettingsFlowWithPasswordMethod
globals()['UpdateSettingsFlowWithProfileMethod'] = UpdateSettingsFlowWithProfileMethod
globals()['UpdateSettingsFlowWithTotpMethod'] = UpdateSettingsFlowWithTotpMethod
globals()['UpdateSettingsFlowWithWebAuthnMethod'] = UpdateSettingsFlowWithWebAuthnMethod
from ory_client.model.update_settings_flow_body import UpdateSettingsFlowBody


class TestUpdateSettingsFlowBody(unittest.TestCase):
    """UpdateSettingsFlowBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateSettingsFlowBody(self):
        """Test UpdateSettingsFlowBody"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateSettingsFlowBody()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
